@@ -3,16 +3,18 @@ from nonebot.adapters.onebot.v11 import (
     GROUP,
     GROUP_ADMIN,
     GROUP_OWNER,
+    PRIVATE,
     Bot,
-    GroupMessageEvent,
     MessageEvent,
-    MessageSegment,
+    GroupMessageEvent,
+    PrivateMessageEvent,
     Message,
+    MessageSegment
 )
 from nonebot.internal.adapter import Bot as BaseBot
 from nonebot.rule import to_me
-from nonebot.typing import T_State
-from nonebot.params import Depends, CommandArg, State
+from nonebot.matcher import Matcher
+from nonebot.params import CommandArg, Arg
 from nonebot.log import logger
 from nonebot.permission import SUPERUSER
 
@@ -24,19 +26,18 @@ import random
 import shutil
 import os
 
-from io import BytesIO
-from nonebot_plugin_imageutils import Text2Image
-
-from .utils import is_number, get_message_at
+from .utils import is_number, get_message_at, text_to_png
 from .data_source import (
     bot_name,
     russian_manager,
     market_manager,
     max_bet_gold,
     race_bet_gold,
-    russian_path
+    russian_path,
+    cache
     )
 from .data_source import constant_props
+from .utils import company_info_Splicing
 
 from .start import *
 from .race_group import race_group
@@ -191,8 +192,7 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
 
         logger.info(f'事件输出:{text}\n{display}')
         
-        output = BytesIO()
-        Text2Image.from_text(display, 50, spacing = 10).to_image("white",(20,20)).save(output, format="png")
+        output = text_to_png(display)
 
         try:
             await RaceStart.send(Message(text) + MessageSegment.image(output))
@@ -295,68 +295,46 @@ async def _(bot: Bot, event: MessageEvent, arg: Message = CommandArg()):
 
 
 
-sign = on_command("金币签到",aliases={"轮盘签到"}, permission=GROUP, priority=5, block=True)
-
-revolt = on_command("发起重置", aliases={"发起revolt","发动revolt", "revolution", "Revolution"},permission=GROUP, priority=5, block=True)
-revolt_sign = on_command("重置签到",aliases={"revolt签到"},permission=GROUP, priority=5, block=True)
-
-give_gold = on_command("打钱", aliases={"发红包", "赠送金币"},permission=GROUP, priority=5, block=True)
-give_props = on_command("送道具", aliases={"赠送道具"},permission=GROUP, priority=5, block=True)
-
-slot = on_command("（已停用）幸运花色", aliases={"（已停用）抽花色"},permission=GROUP, priority=5, block=True)
-gacha = on_command("十连",aliases={"10连"},rule = to_me(),permission=GROUP, priority=5, block=True)
-
-accept = on_command("接受挑战", aliases={"接受决斗", "接受对决"}, permission=GROUP, priority=5, block=True)
-refuse = on_command("拒绝挑战", aliases={"拒绝决斗", "拒绝对决"}, permission=GROUP, priority=5, block=True)
-settlement = on_command("结算", permission=GROUP, priority=5, block=True)
-fold = on_command("结束", permission=GROUP, priority=5, block=True)
-
-russian = on_command("俄罗斯轮盘", aliases={"装弹", "俄罗斯转盘"}, permission=GROUP, priority=5, block=True)
-shot = on_command("开枪", aliases={"咔", "嘭", "嘣"}, permission=GROUP, priority=5, block=True)
-
-dice = on_command("摇骰子",aliases={"摇色子", "掷骰子", "掷色子"}, permission=GROUP, priority=5, block=True)
-dice_open = on_command("取出", aliases={"开数", "开点"},permission=GROUP, priority=5, block=True)
-
-poker = on_command("扑克对战",aliases={"扑克对决", "扑克决斗"}, permission=GROUP, priority=5, block=True)
-poker_play = on_command("出牌", permission=GROUP, priority=5, block=True)
-
-my_gold = on_command("我的金币", permission=GROUP, priority=5, block=True)
-my_info = on_command("我的信息", aliases={"我的资料"}, permission=GROUP, priority=5, block=True)
-my_props = on_command("我的道具", aliases={"我的仓库"}, permission=GROUP, priority=5, block=True)
-
-russian_rank = on_command(
-    "金币排行",
-    aliases = {"胜场排行", "胜利排行", "败场排行", "失败排行", "欧洲人排行", "慈善家排行"},
-    permission=GROUP,
-    priority=5,
-    block=True,
-    )
-name_list = on_command("查看路灯挂件",aliases={"查看路灯","查看挂件"},permission=GROUP, priority=5, block=True)
+# 金币签到
+sign = on_command("金币签到",aliases = {"轮盘签到"}, priority = 5, block = True)
 
 @sign.handle()
-async def _(event: GroupMessageEvent):
-    msg, gold = russian_manager.sign(event)
-    await sign.send(msg, at_sender=True)
-    if gold != -1:
-        logger.info(f"USER {event.user_id} | GROUP {event.group_id} 获取 {gold} 金币")
+async def _(event: MessageEvent):
+    flag =  russian_manager.sign(event)
+    if flag:
+        msg, gold, group_id, user_id = flag
+        if gold != -1:
+            logger.info(f"USER {user_id} | GROUP {group_id} 获取 {gold} 金币")
+        await sign.finish(msg, at_sender=True)
+    else:
+        await sign.finish(f'私聊未关联账户，请先关联群内账户。')
 
 # 发动革命
+revolt = on_command("发起重置", aliases={"发起revolt","发动revolt", "revolution", "Revolution"},permission=GROUP, priority=5, block=True)
+
 @revolt.handle()
-async def _(event: GroupMessageEvent,state: T_State = State()):
-    msg=russian_manager.revlot(event.group_id)
+async def _(event: GroupMessageEvent):
+    msg = russian_manager.revlot(event.group_id)
     if msg:
         await revolt.finish(msg)
     else:
         await revolt.finish()
 # 重置签到
+revolt_sign = on_command("重置签到",aliases = {"revolt签到"}, priority = 5, block = True)
+
 @revolt_sign.handle()
-async def _(event: GroupMessageEvent):
-    msg, gold = russian_manager.revolt_sign(event)
-    await sign.send(msg, at_sender=True)
-    if gold != -1:
-        logger.info(f"USER {event.user_id} | GROUP {event.group_id} 获取 {gold} 金币")
+async def _(event: MessageEvent):
+    flag = russian_manager.revolt_sign(event)
+    if flag:
+        msg, gold, group_id, user_id = flag
+        if gold != -1:
+            logger.info(f"USER {user_id} | GROUP {group_id} 获取 {gold} 金币")
+        await sign.finish(msg, at_sender=True)
+    else:
+        await sign.finish(f'私聊未关联账户，请先关联群内账户。')
 
 # 发红包
+give_gold = on_command("打钱", aliases={"发红包", "赠送金币"},permission=GROUP, priority=5, block=True)
 
 @give_gold.handle()
 async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
@@ -379,6 +357,7 @@ async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
                         await give_gold.finish(msg)
 
 # 送道具
+give_props = on_command("送道具", aliases={"赠送道具"},permission=GROUP, priority=5, block=True)
 
 @give_props.handle()
 async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
@@ -403,6 +382,7 @@ async def _(bot: Bot,event: GroupMessageEvent,arg: Message = CommandArg(),):
             await give_props.finish(msg, at_sender=True)
 
 # 状态处理
+accept = on_command("接受挑战", aliases={"接受决斗", "接受对决"}, permission=GROUP, priority=5, block=True)
 
 @accept.handle()
 async def _(event: GroupMessageEvent):
@@ -412,6 +392,8 @@ async def _(event: GroupMessageEvent):
     else:
         await accept.finish()
 
+refuse = on_command("拒绝挑战", aliases={"拒绝决斗", "拒绝对决"}, permission=GROUP, priority=5, block=True)
+
 @refuse.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     msg = await russian_manager.refuse(bot, event)
@@ -420,6 +402,8 @@ async def _(bot: Bot, event: GroupMessageEvent):
     else:
         await refuse.finish()
 
+settlement = on_command("结算", permission=GROUP, priority=5, block=True)
+
 @settlement.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     msg = russian_manager.settlement(event)
@@ -429,24 +413,18 @@ async def _(bot: Bot, event: GroupMessageEvent):
     else:
         await settlement.finish()
 
+fold = on_command("结束", permission=GROUP, priority=5, block=True)
+
 @fold.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     await russian_manager.fold(bot, event)
 
 # 俄罗斯轮盘
 
-async def get_bullet_num(
-    event: GroupMessageEvent, arg: Message = CommandArg(), state: T_State = State()
-):
-    if state["bullet_num"]:
-        return state
-    else:
-        return None
+russian = on_command("俄罗斯轮盘", aliases={"装弹", "俄罗斯转盘"}, permission=GROUP, priority=5, block=True)
 
 @russian.handle()
-async def _(
-    bot: Bot,event: GroupMessageEvent,state: T_State = State(),arg: Message = CommandArg(),
-):
+async def _(bot: Bot,event: GroupMessageEvent, arg: Message = CommandArg()):
     try:
         _msg = await russian_manager.check_current_game(bot, event)
         if _msg:
@@ -473,48 +451,40 @@ async def _(
             if is_number(msg[1]) and 0 < int(msg[1]):
                 money = int(msg[1])
 
-        state["bullet_num"] = bullet_num
-        state["money"] = money
-        state["at"] = get_message_at(event.json())
-        
-@russian.got("bullet_num")
-async def _(
-    bot: Bot, event: GroupMessageEvent, state: T_State = Depends(get_bullet_num)
-):
-    at_ = state["at"]
-    bullet_num = state["bullet_num"]
-    money = state["money"]
-    user_money = russian_manager.get_user_data(event)["gold"]
-    if money > max_bet_gold:
-        await russian.finish(f"单次金额不能超过{max_bet_gold}", at_sender=True)
-    if money > user_money:
-        await russian.finish("你没有足够的金币支撑这场挑战", at_sender=True)
+        user_money = russian_manager.get_user_data(event)["gold"]
 
-    player1_name = event.sender.card or event.sender.nickname
+        if money > max_bet_gold:
+            await russian.finish(f"单次金额不能超过{max_bet_gold}", at_sender=True)
+        if money > user_money:
+            await russian.finish("你没有足够的金币支撑这场挑战", at_sender=True)
 
-    if at_:
-        at_ = at_[0]
-        at_player_name = await bot.get_group_member_info(group_id=event.group_id, user_id=int(at_))
-        at_player_name = at_player_name["card"] or at_player_name["nickname"]
-        msg = (
-            f"{player1_name} 向 {MessageSegment.at(at_)} 发起挑战！\n"
-            f"请 {at_player_name} 回复 接受挑战 or 拒绝挑战\n"
-            "【30秒内有效】"
-            )
-    else:
-        at_ = 0
-        msg = (
-            f"{player1_name} 发起挑战！\n"
-            "回复 接受挑战 即可开始对局。\n"
-            "【30秒内有效】"
-            )
+        player1_name = event.sender.card or event.sender.nickname
+        at_ = get_message_at(event.json())
+        if at_:
+            at_ = at_[0]
+            at_player_name = await bot.get_group_member_info(group_id=event.group_id, user_id=int(at_))
+            at_player_name = at_player_name["card"] or at_player_name["nickname"]
+            msg = (
+                f"{player1_name} 向 {MessageSegment.at(at_)} 发起挑战！\n"
+                f"请 {at_player_name} 回复 接受挑战 or 拒绝挑战\n"
+                "【30秒内有效】"
+                )
+        else:
+            at_ = 0
+            msg = (
+                f"{player1_name} 发起挑战！\n"
+                "回复 接受挑战 即可开始对局。\n"
+                "【30秒内有效】"
+                )
 
-    info = {
-        "game":"russian",
-        "bullet_num":bullet_num
-        }
-    _msg = russian_manager.ready_game(event, msg, player1_name, at_, money, info)
-    await russian.send(_msg)
+        info = {
+            "game":"russian",
+            "bullet_num":bullet_num
+            }
+        _msg = russian_manager.ready_game(event, msg, player1_name, at_, money, info)
+        await russian.send(_msg)
+
+shot = on_command("开枪", aliases={"咔", "嘭", "嘣"}, permission=GROUP, priority=5, block=True)
 
 @shot.handle()  
 async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
@@ -533,10 +503,10 @@ async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
     await russian_manager.shot(bot, event, count)
 
 # 摇骰子
+dice = on_command("摇骰子",aliases={"摇色子", "掷骰子", "掷色子"}, permission=GROUP, priority=5, block=True)
+
 @dice.handle()
-async def _(
-    bot: Bot,event: GroupMessageEvent,state: T_State = State(),arg: Message = CommandArg(),
-):
+async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg(),):
     try:
         _msg = await russian_manager.check_current_game(bot, event)
         if _msg:
@@ -578,15 +548,17 @@ async def _(
             _msg = russian_manager.ready_game(event, msg, player1_name, at_, money, info)
             await dice.send(_msg)
 
+dice_open = on_command("取出", aliases={"开数", "开点"},permission=GROUP, priority=5, block=True)
+
 @dice_open.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     await russian_manager.dice_open(bot, event)
 
 # 扑克对战
+poker = on_command("扑克对战",aliases={"扑克对决", "扑克决斗"}, permission=GROUP, priority=5, block=True)
+
 @poker.handle()
-async def _(
-    bot: Bot,event: GroupMessageEvent,state: T_State = State(),arg: Message = CommandArg(),
-):
+async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg(),):
     try:
         _msg = await russian_manager.check_current_game(bot, event)
         if _msg:
@@ -628,31 +600,76 @@ async def _(
             _msg = russian_manager.ready_game(event, msg, player1_name, at_, money, info)
             await poker.send(_msg)
 
+poker_play = on_command("出牌", permission=GROUP, priority=5, block=True)
+
 @poker_play.handle()
 async def _(bot: Bot, event: GroupMessageEvent, arg: Message = CommandArg()):
     card = arg.extract_plain_text().strip()
     await russian_manager.poker_play(bot, event, card)
 
+# 关联账户
+connect = on_command("连接账户", aliases = {"关联账户"}, rule = to_me(), priority = 5, block = True)
+
+@connect.handle()
+async def _(bot: Bot, event: MessageEvent, matcher: Matcher):
+    user_id = str(event.user_id)
+    if isinstance(event,GroupMessageEvent):
+        russian_manager._init_player_data(event)
+        russian_manager.connect_data[user_id] = str(event.group_id)
+        russian_manager.connect_save()
+        await connect.finish("私聊账户已关联到本群", at_sender=True)
+    else:
+        player = russian_manager._player_data
+        msg = "你的账户\n"
+        group_list = []
+        for group_id in player.keys():
+            if user_id in player[group_id].keys():
+                msg += f'{group_id} 金币：{player[group_id][user_id]["gold"]} 枚\n'
+                group_list.append(group_id)
+        else:
+            msg += "\n请输入你要关联的群号"
+        matcher.set_arg("group_list", group_list)
+        await asyncio.sleep(2)
+        await connect.send(msg)
+
+@connect.got("group_id")
+
+async def _(bot:Bot, event: MessageEvent, matcher: Matcher, group_id : Message = Arg()):
+    group_id = str(group_id).strip()
+    group_list = matcher.get_arg("group_list")
+    if group_id in group_list:
+        russian_manager.connect_data[str(event.user_id)] = group_id
+        russian_manager.connect_save()
+        await connect.finish(f"私聊账户已关联到{group_id}")
+    else:
+        await connect.finish(f"未关联")
+
 # 幸运花色
+slot = on_command("幸运花色", aliases={"抽花色"}, permission = PRIVATE, priority=5, block=True)
+
 @slot.handle()
-async def _(bot: Bot, event: GroupMessageEvent,arg: Message = CommandArg()):
+async def _(bot: Bot, event: PrivateMessageEvent,arg: Message = CommandArg()):
     gold = 50
     if arg:
-        if is_number(str(arg)):
-            tmp = abs(int(str(arg)))
-            if 0 < tmp <= int(max_bet_gold/2):
-                gold = abs(int(str(arg)))
+        arg = str(arg)
+        if is_number(arg):
+            gold = abs(int(arg))
+    else:
+        gold = 50
 
     msg = russian_manager.slot(event,gold)
     await slot.finish(msg, at_sender=True)
 
 # 十连抽卡
+gacha = on_command("十连", aliases = {"10连"}, rule = to_me(), priority = 5, block = True)
+
 @gacha.handle()
-async def _(bot: Bot, event: GroupMessageEvent,arg: Message = CommandArg()):
+async def _(bot: Bot, event: MessageEvent,arg: Message = CommandArg()):
     msg = russian_manager.gacha(event)
     await gacha.finish(msg, at_sender=True)
 
 # 我的
+my_props = on_command("我的道具", aliases={"我的仓库"}, permission=GROUP, priority=5, block=True)
 
 @my_props.handle()
 async def _(event: GroupMessageEvent):
@@ -671,30 +688,48 @@ async def _(event: GroupMessageEvent):
         props_info = "你的仓库空空如也..."
     await my_props.finish(props_info,at_sender=True)
 
+my_gold = on_command("我的金币", priority=5, block=True)
+
 @my_gold.handle()
-async def _(event: GroupMessageEvent):
-    gold = russian_manager.get_user_data(event)["gold"]
-    await my_gold.finish(f"你还有 {gold} 枚金币", at_sender=True)
+async def _(event: MessageEvent):
+    user_data = russian_manager.try_get_user_data(event)[0]
+    if user_data:
+        await my_gold.finish(f'你还有 {user_data["gold"]} 枚金币', at_sender=True)
+    else:
+        await my_gold.finish(f'私聊未关联账户，请先关联群内账户。')
+
+my_info = on_command("我的信息", aliases={"我的资料"}, priority=5, block=True)
 
 @my_info.handle()
-async def _(event: GroupMessageEvent):
+async def _(event: MessageEvent):
     info = russian_manager.my_info(event)
-    output = BytesIO()
-    Text2Image.from_text(info[:-1],50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
-    await my_info.finish(MessageSegment.image(output))
+    if info:
+        output = text_to_png(info[:-1], 12)
+        await my_info.finish(MessageSegment.image(output))
+    else:
+        await my_info.finish(f'私聊未关联账户，请先关联群内账户。')
 
 # 查看排行榜
+russian_rank = on_command(
+    "金币排行",
+    aliases = {"胜场排行", "胜利排行", "败场排行", "失败排行", "欧洲人排行", "慈善家排行"},
+    permission=GROUP,
+    priority=5,
+    block=True,
+    )
+
 @russian_rank.handle()
-async def _(event: GroupMessageEvent, state: T_State = State()):
-    msg = await russian_manager.rank(state["_prefix"]["raw_command"], event.group_id)
+async def _(event: GroupMessageEvent):
+    msg = await russian_manager.rank(event.raw_message, event.group_id)
     if msg:
-        output = BytesIO()
-        Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+        output = text_to_png(msg)
         await russian_rank.finish(MessageSegment.image(output))
     else:
         await russian_rank.finish()
 
 # 查看路灯挂件
+name_list = on_command("查看路灯挂件",aliases={"查看路灯","查看挂件"},permission=GROUP, priority=5, block=True)
+
 @name_list.handle()
 async def _(event: GroupMessageEvent):
     group_id = str(event.group_id)
@@ -713,36 +748,16 @@ async def _(event: GroupMessageEvent):
             rst += f"{name}：达成{_max}次\n"
             all_user_data.remove(_max)
             all_user.remove(_max_id)
-        else:
-            rst = rst[:-1]
         if rst:
-            await name_list.finish("☆ ☆ 路灯挂件榜 ☆ ☆\n" + rst)
+            await name_list.finish("☆ ☆ 路灯挂件榜 ☆ ☆\n" + rst[:-1])
         else:
             await name_list.finish("群内没有路灯挂件。")
     else:
         await name_list.finish()
 
-
-
+# 公司上市
 Market_public = on_command("市场注册",aliases={"公司注册","注册公司"},rule = to_me(),permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
 
-company_buy = on_command("发行购买",aliases={"发行买入"},permission=GROUP, priority=5, block=True)
-company_clear = on_command("官方结算",permission=GROUP, priority=5, block=True)
-
-Market_buy = on_command("买入",aliases={"购买","购入"},permission=GROUP, priority=5, block=True)
-Market_sell = on_command("卖出",aliases={"出售","上架"},permission=GROUP, priority=5, block=True)
-
-Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
-Market_info_pro = on_command("市场行情",aliases={"市场走势","市场详细信息"}, priority=5, block=True)
-
-company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
-
-update_intro = on_command("更新公司简介",aliases={"添加公司简介"},permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
-update_intro_superuser = on_command("管理员更新公司简介",aliases={"管理员更新公司简介"},permission=SUPERUSER, priority=5, block=True)
-
-intergroup_transfer = on_command("金币转移", permission=GROUP, priority=5, block=True)
-
-# 公司上市
 @Market_public.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -750,7 +765,7 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         msg = msg.split()
         if len(msg) == 1:
             msg = msg[0]
-            msg = market_manager.Market_public(event,msg)
+            msg = market_manager.public(event,msg)
             await Market_public.finish(msg)
         else:
             await Market_public.finish(f"错误：公司名称格式错误\n{str(msg)}")
@@ -758,6 +773,8 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         await Market_public.finish("错误：未设置公司名称")
 
 # 发行购买
+company_buy = on_command("发行购买",aliases={"发行买入"},permission=GROUP, priority=5, block=True)
+
 @company_buy.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -770,13 +787,14 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
             try:
                 await company_buy.send(msg)
             except:
-                output = BytesIO()
-                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                output = text_to_png(msg)
                 await company_buy.send(MessageSegment.image(output))
             finally:
                 await company_buy.finish()
 
 # 债务清算
+company_clear = on_command("官方结算",permission=GROUP, priority=5, block=True)
+
 @company_clear.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -789,13 +807,14 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
             try:
                 await company_clear.send(msg)
             except:
-                output = BytesIO()
-                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                output = text_to_png(msg)
                 await company_clear.send(MessageSegment.image(output))
             finally:
                 await company_clear.finish()
 
 # 市场买入
+Market_buy = on_command("买入",aliases={"购买","购入"},permission=GROUP, priority=5, block=True)
+
 @Market_buy.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -808,13 +827,14 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
             try:
                 await Market_buy.send(msg)
             except:
-                output = BytesIO()
-                Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                output = text_to_png(msg)
                 await Market_buy.send(MessageSegment.image(output))
             finally:
                 await Market_buy.finish()
 
 # 市场卖出
+Market_sell = on_command("卖出",aliases={"出售","上架"},permission=GROUP, priority=5, block=True)
+
 @Market_sell.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -829,45 +849,57 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
                 try:
                     await Market_sell.send(msg)
                 except:
-                    output = BytesIO()
-                    Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+                    output = text_to_png(msg)
                     await Market_sell.send(MessageSegment.image(output))
                 finally:
                     await Market_sell.finish()
 
 # 市场信息
+Market_info = on_command("市场信息",aliases={"查看市场"}, priority=5, block=True)
+
 @Market_info.handle()
 async def _(bot:Bot, event: MessageEvent,arg: Message = CommandArg()):
     company_name = arg.extract_plain_text().strip()
     if company_name:
         company_name = company_name.split()
-        if len(company_name) == 1:
-            company_name = company_name[0]
-        else:
-            company_name == ""
+        company_name = company_name[0]
     else:
         company_name == ""
-    msg = market_manager.Market_info(event,company_name)
-    if type(msg) == list:
-        await bot.send_group_forward_msg(group_id=event.group_id, messages = msg)
-        await Market_info.finish()
-    else:
-        await Market_info.finish(msg)
 
-# 市场走势
-@Market_info_pro.handle()
-async def _(bot:Bot, event: MessageEvent):
-    msg = market_manager.Market_info_pro(event)
+    msg = market_manager.Market_info(event,company_name)
+
     if type(msg) == list:
         if isinstance(event, GroupMessageEvent):
             await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
         else:
             await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
-        await Market_info_pro.finish()
+        await Market_info.finish()
     else:
-        await Market_info_pro.finish(msg)
+        await Market_info.finish(msg)
+
+# 市场走势
+Market_ohlc = on_command("市场行情",aliases={"市场走势"}, priority=5, block=True)
+
+@Market_ohlc.handle()
+async def _(bot:Bot, event: MessageEvent):
+    if market_manager.ohlc_temp[1] <= 6:
+        msg = market_manager.ohlc_temp[0]
+    else:
+        await Market_ohlc.send("正在生成走势图...")
+        msg = await market_manager.ohlc(event)
+
+    if type(msg) == list:
+        if isinstance(event, GroupMessageEvent):
+            await bot.send_group_forward_msg(group_id = event.group_id, messages = msg)
+        else:
+            await bot.send_private_forward_msg(user_id = event.user_id, messages = msg)
+        await Market_ohlc.finish()
+    else:
+        await Market_ohlc.finish(msg)
 
 # 公司信息
+company_info = on_command("公司信息",aliases={"公司资料"}, priority=5, block=True)
+
 @company_info.handle()
 async def _(event: MessageEvent,arg: Message = CommandArg()):
     company_name = arg.extract_plain_text().strip()
@@ -876,12 +908,18 @@ async def _(event: MessageEvent,arg: Message = CommandArg()):
         company_name = company_name[0]
         msg = market_manager.company_info(company_name)
         if msg:
-            output = BytesIO()
-            Text2Image.from_text(msg,50,spacing = 10).to_image("white",(20,20)).save(output, format="png")
+            if os.path.exists(cache / "ohlc.json"):
+                with open(cache / "ohlc.json", "r", encoding="utf8") as f:
+                    ohlc = json.load(f)
+                output = company_info_Splicing(msg ,ohlc[company_name])
+            else:
+                output = text_to_png(msg)
             await company_info.finish(MessageSegment.image(output))
         else:
             await company_info.finish(f"【{company_name}】未注册")
 # 更新公司简介
+update_intro = on_command("更新公司简介",aliases={"添加公司简介"},permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=5, block=True)
+
 @update_intro.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     intro = arg.extract_plain_text().strip()
@@ -897,6 +935,8 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         await update_intro.finish()
 
 # 管理员更新简介
+update_intro_superuser = on_command("管理员更新公司简介",aliases={"管理员更新公司简介"},permission=SUPERUSER, priority=5, block=True)
+
 @update_intro_superuser.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip()
@@ -906,6 +946,8 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         await update_intro_superuser.finish("简介更新完成...")
 
 # 跨群转移金币到自己的账户
+intergroup_transfer = on_command("金币转移", permission=GROUP, priority=5, block=True)
+
 @intergroup_transfer.handle()
 async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
     msg = arg.extract_plain_text().strip().split()
@@ -915,42 +957,37 @@ async def _(event: GroupMessageEvent,arg: Message = CommandArg()):
         msg = market_manager.intergroup_transfer(event,company_name,gold)
         await intergroup_transfer.finish(msg, at_sender=True)
 
+# 股票回收
+repurchase = on_command("股票回收",aliases={"回收股票"} ,rule = to_me() , permission = SUPERUSER, priority=5, block = True)
 
+@repurchase.handle()
+async def _(bot:Bot):
+    await repurchase.send("正在启动回收程序。")
+    msg = await market_manager.repurchase(bot)
+    await repurchase.finish(msg)
 
-reset_sign = on_command("reset_sign", permission=SUPERUSER, priority=5, block=True) # 重置每日签到和每日补贴
+# 公司退市
+delist = on_command("公司退市",aliases={"清理市场", "市场清理"} ,rule = to_me() , permission = SUPERUSER, priority=5, block = True)
+
+@delist.handle()
+async def _(bot:Bot):
+    await delist.send("正在启动退市程序。")
+    msg = await market_manager.delist(bot)
+    await delist.finish(msg)
 
 # 刷新每日签到和每日补贴
-@reset_sign.handle()
-async def _():
-    russian_manager.reset_gold()
-    logger.info("签到重置成功...")
-    russian_manager.reset_security()
-    logger.info("补贴重置成功...")
+reset_sign = on_command("reset_sign", permission=SUPERUSER, priority=5, block=True) # 重置每日签到和每日补贴
 
-# 刷新每日签到，每日补贴，每日利息发放
-@scheduler.scheduled_job("cron", hour=0, minute=0)
+@reset_sign.handle()
+@scheduler.scheduled_job("cron", hour = 0)
 async def _():
-    russian_manager.reset_gold()
+    russian_manager.reset_sign()
     logger.info("今日签到重置成功...")
     russian_manager.reset_security()
     logger.info("今日补贴重置成功...")
-    russian_manager.interest()
-    logger.info("今日利息已发放...")
-
-# 重置幸运花色
-'''
-@scheduler.scheduled_job("cron",minute = "0,30")
-async def _():
-    for group_id in russian_manager._player_data.keys():
-        for user_id in russian_manager._player_data[group_id].keys():
-            russian_manager._player_data[group_id][user_id]["slot"] = 0
-
-    logger.info("幸运花色已重置...")
-    russian_manager.save()
-'''
      
 # 刷新道具时间
-@scheduler.scheduled_job("cron", hour = 4, minute = 0)
+@scheduler.scheduled_job("cron", hour = 4)
 async def _():
     for group_id in russian_manager._player_data.keys():
         for user_id in russian_manager._player_data[group_id].keys():
@@ -977,14 +1014,14 @@ async def _():
             market_manager.company_update(group_id)
             logger.info(f'【{market_manager._market_data[group_id]["company_name"]}】更新成功...')
     else:
-        market_manager.info_temp[1] = 0
+        market_manager.ohlc_temp[1] += 1
         russian_manager.save()
         market_manager.market_data_save()
         market_manager.market_history_save()
 
 # 数据备份
 
-@scheduler.scheduled_job("cron",hour = "4,10,16,22")
+@scheduler.scheduled_job("cron", hour = "4,10,16,22")
 async def _():
     now = time.strftime('%Y-%m-%d-%H', time.localtime(time.time()))
     path =f"{russian_path}/data/russian"
